@@ -156,6 +156,7 @@ class Exchange(Account):
         from threading import Thread
 
         self.__auto_renew_thread = Thread(target=self.__auto_renew_session)
+        self.__auto_renew_thread.daemon = True
         self.__auto_renew_thread.start()
 
     def __auto_renew_session(self):
@@ -165,6 +166,7 @@ class Exchange(Account):
 
         while self.__auto_renew:
             if counter > 70:
+                counter = 0
                 self.renew_session()
 
             sleep(1)
