@@ -78,16 +78,17 @@ class LogHandle(object):
         else:
             self.__gui_console = GUIConsole(parent=self, title=title)
 
-    def write_to_log(self, message, action='info'):
+    def write_to_log(self, message, action='info', print_only=False):
         """
         Logging becomes more organized!
 
         :param message: Message that you would like to write to log
         :param action: What kind of action would you like the entry to be marked as?
             (debug, info, warning, error, critical)
+        :param print_only: (True/False) print line only and not log into file
         """
 
-        if self.__base_name and self.__file_dir:
+        if not print_only and self.__base_name and self.__file_dir:
             if not message:
                 raise Exception("'message' is missing")
 
@@ -103,7 +104,7 @@ class LogHandle(object):
         else:
             print('{0} - {1} - {2}'.format(datetime.now(), action.upper(), message))
 
-        if self.__base_name and self.__file_dir:
+        if not print_only and self.__base_name and self.__file_dir:
             if action.lower() == 'debug':
                 logging.debug(message)
             elif action.lower() == 'info':
