@@ -144,6 +144,8 @@ class TBoxBase(object):
 
 
 class Toolbox(TBoxBase, SQLQueue, LogHandle):
+    DEFAULT_CONNECTION_SIZE = 10
+
     def __init__(self, script_path, logging_dir=None, logging_base_name=None, max_pool_size=None,
                  *args, **kwargs):
         if logging_dir and os.path.exists(logging_dir) and os.path.isdir(logging_dir):
@@ -161,26 +163,30 @@ class Toolbox(TBoxBase, SQLQueue, LogHandle):
         SQLQueue.__init__(self, max_pool_size=max_pool_size)
         LogHandle.__init__(self, file_dir=file_dir, base_name=base_name)
 
-    def config_sql_conn(self, sql_config):
+    def config_sql_conn(self, sql_config, new_instance=False, conn_max_pool_size=DEFAULT_CONNECTION_SIZE):
         """
         Create a custom SQL connection and add engine to SQL queue pool
 
         :param sql_config: SQLConfig class instance that can be customizable
+        :param new_instance: Creates a new instance of default sql connection (Default False)
+        :param conn_max_pool_size: Maximum of sql connections (Optional)
         :return: SQL Engine (Engine is still in queue pool)
         """
 
         engine = self.__find_engine(sql_config)
 
-        if engine is None:
-            self.create_sql_engine_to_pool(sql_config=sql_config)
+        if new_instance or engine is None:
+            self.create_sql_engine_to_pool(sql_config=sql_config, conn_max_pool_size=conn_max_pool_size)
             engine = self.__find_engine(sql_config)
 
         return engine
 
-    def default_sql_conn(self):
+    def default_sql_conn(self, new_instance=False, conn_max_pool_size=DEFAULT_CONNECTION_SIZE):
         """
         Creates the default SQL connection and add engine to SQL queue pool
 
+        :param new_instance: Creates a new instance of default sql connection (Default False)
+        :param conn_max_pool_size: Maximum of sql connections (Optional)
         :return: SQL Engine (Engine is still in queue pool)
         """
 
@@ -224,8 +230,8 @@ class Toolbox(TBoxBase, SQLQueue, LogHandle):
 
             engine = self.__find_engine(sql_config)
 
-            if engine is None:
-                self.create_sql_engine_to_pool(sql_config=sql_config)
+            if new_instance or engine is None:
+                self.create_sql_engine_to_pool(sql_config=sql_config, conn_max_pool_size=conn_max_pool_size)
                 engine = self.__find_engine(sql_config)
 
                 if not engine and redo_settings(self.main_config):
